@@ -22,6 +22,7 @@ from minFQ.fastq_handler_utils import (
 from watchdog.events import FileSystemEventHandler
 
 log = logging.getLogger(__name__)
+log.setLevel(logging.DEBUG)
 
 
 # ##Function modified from https://raw.githubusercontent.com/lh3/readfq/master/readfq.py
@@ -101,7 +102,6 @@ def parse_fastq_record(
     -------
 
     """
-    log.debug("Parsing reads from file {}".format(fastq_file_path))
     fastq_read = {
         "read": description_dict.get("read", None),
         "run_id": description_dict.get("runid", None),
@@ -128,7 +128,7 @@ def parse_fastq_record(
     if args.unblocks is not None:
         run_dict[fastq_read["run_id"]].unblocked_file = args.unblocks
     ### Check the overlap between the current file path and the folders being watched:
-    for folder in sequencing_statistic.directory_watch_list:
+    for folder in sequencing_statistic.watched_directory_set:
         if folder is not None:
             if fastq_file_path.startswith(folder):
                 if run_dict[fastq_read["run_id"]].run_folder != folder:
@@ -175,6 +175,7 @@ def parse_fastq_record(
         run_dict[fastq_read["run_id"]].add_read(fastq_read)
     else:
         sequencing_statistic.reads_skipped += 1
+        sequencing_statistic.fastq_info[fastq_read["run_id"]]["reads_skipped"] += 1
 
 
 def parse_fastq_file(
@@ -187,7 +188,7 @@ def parse_fastq_file(
     fastq_path: str
         Path to the fastq file to parse
     run_dict: dict
-        Dictionary conating the run 
+        Dictionary containing the run
     args: argparse.NameSpace
         The namespace of the parsed command line args
     header: dict
@@ -216,6 +217,7 @@ def parse_fastq_file(
         fastq_file = minotour_api.post(
             EndPoint.FASTQ_FILE, json=payload, base_id=run_id
         )
+    sequencing_stats.fastq_info[run_id]["run_id"] = run_id
     counter = 0
     # fq = pyfastx.Fastq(fastq_path)
     # gen = (read for read in fq)
@@ -226,6 +228,7 @@ def parse_fastq_file(
             description_dict = parse_fastq_description(desc)
             counter += 1
             sequencing_stats.reads_seen += 1
+            sequencing_stats.fastq_info[run_id]["reads_seen"] += 1
             sequencing_stats.fastq_message = "processing read {}".format(counter)
             try:
                 ### We haven't seen this run before - so we need to check stuff.
@@ -258,8 +261,7 @@ def parse_fastq_file(
 
             except Exception as e:
                 sequencing_stats.reads_corrupt += 1
-                print(e)
-                log.error(e)
+                log.error(e, exc_info=True)
                 log.error("This gzipped file failed to upload - {}.".format(fastq_path))
                 raise Exception
                 # continue
@@ -279,6 +281,7 @@ def parse_fastq_file(
     except Exception as err:
         log.error("Problem with uploading file {}".format(err))
     sequencing_stats.time_per_file = time.time()
+    sequencing_stats.fastq_info[run_id]["files_processed"] += 1
     return counter
 
 
@@ -348,11 +351,13 @@ class FastqHandler(FileSystemEventHandler):
         while self.running:
             current_time = time.time()
             # sort by created time descending
-            for fastqfile, createtime in sorted(
+            for fastqfile, create_time in sorted(
                 self.fastq_files_to_create.items(), key=lambda x: x[1]
             ):
-                # file created 5 sec ago, so should be complete. For simulations we make the time longer.
                 # remove the file from fastq files to create as we are doing that now
+                if create_time > time.time() - 5:
+                    time.sleep(5)
+                # file created 5 sec ago, so should be complete. For simulations we make the time longer.
                 del self.fastq_files_to_create[fastqfile]
                 parse_fastq_file(
                     fastqfile,
@@ -368,7 +373,6 @@ class FastqHandler(FileSystemEventHandler):
                     break
             if current_time + 5 > time.time():
                 time.sleep(5)
-            log.debug("still ticking")
 
     def on_created(self, event):
         """Watchdog counts a new file in a folder it is watching as a new file"""
@@ -376,7 +380,7 @@ class FastqHandler(FileSystemEventHandler):
         # if (event.src_path.endswith(".fastq") or event.src_path.endswith(".fastq.gz")):
         #     self.creates[event.src_path] = time.time()
 
-        log.debug("Processing file {}".format(event.src_path))
+        log.debug("Processing created file {}".format(event.src_path))
         # time.sleep(5)
         if (
             event.src_path.endswith(".fastq")
@@ -385,6 +389,8 @@ class FastqHandler(FileSystemEventHandler):
             or event.src_path.endswith(".fq.gz")
         ):
             self.sequencing_statistic.files_seen += 1
+            run_id = get_runid(event.src_path)
+            self.sequencing_statistic.fastq_info[run_id]["files_seen"] += 1
             self.fastq_files_to_create[event.src_path] = time.time()
 
     def on_modified(self, event):
@@ -401,8 +407,8 @@ class FastqHandler(FileSystemEventHandler):
         if any(
             (
                 event.dest_path.endswith(".fastq"),
-                event.dest_path.endswith(".fastq,gz"),
-                event.dest_path.endswith(".gq"),
+                event.dest_path.endswith(".fastq.gz"),
+                event.dest_path.endswith(".fq"),
                 event.dest_path.endswith(".fq.gz"),
             )
         ):
